@@ -1,12 +1,13 @@
 from .dead_letter_queue import DeadLetterQueue
-from .policies.abstract import InvalidMessage
+from .policies.abstract import DeadLetterQueuePolicy, InvalidMessages
 from .policies.count import CountInvalidMessagePolicy
 from .policies.ignore import IgnoreInvalidMessagePolicy
 from .policies.raise_e import RaiseInvalidMessagePolicy
 
 __all__ = [
     "DeadLetterQueue",
-    "InvalidMessage",
+    "InvalidMessages",
+    "DeadLetterQueuePolicy",
     "CountInvalidMessagePolicy",
     "IgnoreInvalidMessagePolicy",
     "RaiseInvalidMessagePolicy",
