@@ -1,6 +1,6 @@
 from arroyo.processing.strategies.dead_letter_queue.policies.abstract import (
     DeadLetterQueuePolicy,
-    InvalidMessage,
+    InvalidMessages,
 )
 from arroyo.utils.metrics import get_metrics
 
@@ -9,5 +9,5 @@ class IgnoreInvalidMessagePolicy(DeadLetterQueuePolicy):
     def __init__(self) -> None:
         self.__metrics = get_metrics()
 
-    def handle_invalid_message(self, e: InvalidMessage) -> None:
-        self.__metrics.increment("dlq.dropped_message")
+    def handle_invalid_messages(self, e: InvalidMessages) -> None:
+        self.__metrics.increment("dlq.dropped_messages", len(e.messages))
