@@ -4,6 +4,7 @@ import pickle
 import signal
 import time
 from collections import deque
+from functools import partial
 from multiprocessing.managers import SharedMemoryManager
 from multiprocessing.pool import AsyncResult, Pool
 from multiprocessing.shared_memory import SharedMemory
@@ -141,7 +142,7 @@ class MessageBatch(Generic[TPayload]):
         return pickle.loads(
             data,
             buffers=[
-                self.block.buf[offset : offset + length].tobytes()
+                self.block.buf[offset: offset + length].tobytes()
                 for offset, length in buffers
             ],
         )
@@ -178,7 +179,7 @@ class MessageBatch(Generic[TPayload]):
                 raise ValueTooLarge(
                     f"value exceeds available space in block, {length} bytes needed but {self.block.size - offset} bytes free"
                 )
-            self.block.buf[offset : offset + length] = value
+            self.block.buf[offset: offset + length] = value
             self.__offset += length
             buffers.append((offset, length))
 
@@ -213,11 +214,16 @@ class BatchBuilder(Generic[TPayload]):
         return self.__batch
 
 
-def parallel_transform_worker_initializer() -> None:
+def parallel_transform_worker_initializer(
+    custom_initialize_func: Optional[Callable[[], None]] = None
+) -> None:
     # Worker process should ignore ``SIGINT`` so that processing is not
     # interrupted by ``KeyboardInterrupt`` during graceful shutdown.
     signal.signal(signal.SIGINT, signal.SIG_IGN)
 
+    if custom_initialize_func is not None:
+        custom_initialize_func()
+
 
 def parallel_transform_worker_apply(
     function: Callable[[Message[TPayload]], TTransformed],
@@ -276,6 +282,7 @@ class ParallelTransformStep(ProcessingStep[TPayload]):
         max_batch_time: float,
         input_block_size: int,
         output_block_size: int,
+        initializer: Optional[Callable[[], None]] = None,
     ) -> None:
         self.__transform_function = function
         self.__next_step = next_step
@@ -287,7 +294,7 @@ class ParallelTransformStep(ProcessingStep[TPayload]):
 
         self.__pool = Pool(
             processes,
-            initializer=parallel_transform_worker_initializer,
+            initializer=partial(parallel_transform_worker_initializer, initializer),
             context=multiprocessing.get_context("spawn"),
         )
 
@@ -313,6 +320,7 @@ class ParallelTransformStep(ProcessingStep[TPayload]):
         self.__metrics = get_metrics()
         self.__batches_in_progress = Gauge(self.__metrics, "batches_in_progress")
         self.__pool_waiting_time: Optional[float] = None
+        self.__metrics.gauge("transform.processes", processes)
 
         self.__closed = False
 
@@ -376,12 +384,7 @@ class ParallelTransformStep(ProcessingStep[TPayload]):
                 input_batch,
                 self.__pool.apply_async(
                     parallel_transform_worker_apply,
-                    (
-                        self.__transform_function,
-                        input_batch,
-                        output_batch.block,
-                        i,
-                    ),
+                    (self.__transform_function, input_batch, output_batch.block, i,),
                 ),
             )
             return
@@ -426,9 +429,7 @@ class ParallelTransformStep(ProcessingStep[TPayload]):
             raise MessageRejected("no available input blocks") from e
 
         self.__batch_builder = BatchBuilder(
-            MessageBatch(input_block),
-            self.__max_batch_size,
-            self.__max_batch_time,
+            MessageBatch(input_block), self.__max_batch_size, self.__max_batch_time,
         )
 
     def submit(self, message: Message[TPayload]) -> None:
@@ -463,13 +464,13 @@ class ParallelTransformStep(ProcessingStep[TPayload]):
     def terminate(self) -> None:
         self.__closed = True
 
-        logger.debug("Terminating %r...", self.__pool)
+        logger.info("Terminating %r...", self.__pool)
         self.__pool.terminate()
 
-        logger.debug("Shutting down %r...", self.__shared_memory_manager)
+        logger.info("Shutting down %r...", self.__shared_memory_manager)
         self.__shared_memory_manager.shutdown()
 
-        logger.debug("Terminating %r...", self.__next_step)
+        logger.info("Terminating %r...", self.__next_step)
         self.__next_step.terminate()
 
     def join(self, timeout: Optional[float] = None) -> None:
